@@ -69,7 +69,7 @@ def start_player(entry, rpc_client=None, player=None):
     hist_class = history(entry)
     hist_class.write_hist()
 
-    if config.dc_presence:
+    if rpc_client:
         dc_media_title = f"{entry.show_name} | {entry.ep}/{entry.latest_ep}"
         dc_presence(dc_media_title, entry.category_url, rpc_client)
 
